@@ -3,7 +3,7 @@ package Calendar::Indonesia::Holiday;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-13'; # DATE
 our $DIST = 'Calendar-Indonesia-Holiday'; # DIST
-our $VERSION = '0.331'; # VERSION
+our $VERSION = '0.332'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1240,6 +1240,7 @@ _
         year       => {schema=>'int*'},
         date       => {schema=>'str*', pos=>0},
 
+        include_joint_leave => {schema=>'bool*', cmdline_aliases=>{j=>{}}},
         reverse    => {schema=>'bool*', cmdline_aliases=>{r=>{}}},
         quiet      => {schema=>'bool*', cmdline_aliases=>{q=>{}}},
         detail     => {schema=>'bool*', cmdline_aliases=>{l=>{}}},
@@ -1311,7 +1312,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.331 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-01-13.
+This document describes version 0.332 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2021-01-13.
 
 =head1 SYNOPSIS
 
@@ -1539,6 +1540,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<detail> => I<bool>
 
+=item * B<include_joint_leave> => I<bool>
+
 =item * B<month> => I<int>
 
 =item * B<quiet> => I<bool>
